summaryrefslogtreecommitdiffstats
path: root/libktorrent/util/log.h
diff options
context:
space:
mode:
Diffstat (limited to 'libktorrent/util/log.h')
-rw-r--r--libktorrent/util/log.h18
1 files changed, 9 insertions, 9 deletions
diff --git a/libktorrent/util/log.h b/libktorrent/util/log.h
index 2fe0ba6..742b753 100644
--- a/libktorrent/util/log.h
+++ b/libktorrent/util/log.h
@@ -23,7 +23,7 @@
#include "constants.h"
-#include <qstring.h>
+#include <tqstring.h>
// LOG MESSAGES CONSTANTS
#define LOG_NONE 0x00
@@ -115,18 +115,18 @@ namespace bt
* @param file The name of the file
* @throw Exception if the file can't be opened
*/
- void setOutputFile(const QString & file);
+ void setOutputFile(const TQString & file);
/**
* Write a number to the log file.
* Anything which can be passed to QString::number will do.
* @param val The value
* @return This Log
*/
template <class T>
Log & operator << (T val)
{
- return operator << (QString::number(val));
+ return operator << (TQString::number(val));
}
/**
@@ -141,18 +141,18 @@ namespace bt
/**
* Output a QString to the log.
* @param s The QString
* @return This Log
*/
Log & operator << (const char* s);
/**
* Output a QString to the log.
* @param s The QString
* @return This Log
*/
- Log & operator << (const QString & s);
+ Log & operator << (const TQString & s);
/**
* Output a 64 bit integer to the log.
@@ -115,18 +115,18 @@ namespace bt
/**
* Write a number to the log file.
- * Anything which can be passed to QString::number will do.
+ * Anything which can be passed to TQString::number will do.
* @param val The value
* @return This Log
@@ -141,18 +141,18 @@ namespace bt
/**
- * Output a QString to the log.
- * @param s The QString
+ * Output a TQString to the log.
+ * @param s The TQString
* @return This Log
*/
@@ -141,18 +141,18 @@ namespace bt
Log & operator << (const char* s);
/**
- * Output a QString to the log.
- * @param s The QString
+ * Output a TQString to the log.
+ * @param s The TQString
* @return This Log
*/